@@ -9,7 +9,7 @@ use fields qw( buffer buffered from subject to );
 
 use vars qw[ $VERSION ];
 
-$VERSION = sprintf "%d.%03d", q$Revision: 1.9 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%03d", q$Revision: 1.11 $ =~ /: (\d+)\.(\d+)/;
 
 1;
 
@@ -36,6 +36,8 @@ sub new
     # Default to buffered for obvious reasons!
     $self->{buffered} = exists $params{buffered} ? $params{buffered} : 1;
 
+    $self->{buffer} = [] if $self->{buffered};
+
     return $self;
 }
 
@@ -69,7 +71,7 @@ sub DESTROY
 {
     my Log::Dispatch::Email $self = shift;
 
-    if ($self->{buffered})
+    if ($self->{buffered} && @{ $self->{buffer} })
     {
 	my $message = join '', @{ $self->{buffer} };
 
